﻿using Newtonsoft.Json.Linq;
using PushipApi;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Globalization;
using System.Net.Http;
using System.Text;
using System.Windows.Forms;

namespace Sample
{
    public partial class SampleForm : Form
    {
        public SampleForm()
        {
            InitializeComponent();
        }

        private async void btnGetDevices_Click(object sender, EventArgs e)
        {
            Credentials cr = new Credentials(ConfigClass.Username, ConfigClass.Password);
            CoreApi ca = new CoreApi(ConfigClass.AppId, cr);
            
            try
            {
                Dictionary<String, Object> param = new Dictionary<String, Object>();
                param.Add("DeviceType", "3"); //Android platform filter
                param.Add("Limit", "10");
                param.Add("Offset", "0");

                //param.Add("P1Latitude", "40.42163694648697");
                //param.Add("P1Longitude", "10.299156188964844");
                //param.Add("P2Latitude", "47.45030563100575");
                //param.Add("P2Longitude", "15.368927001953125");

                param.Add("Expired", "True");

                TimeZoneInfo tm = TimeZoneInfo.FindSystemTimeZoneById("W. Europe Standard Time"); //http://msdn.microsoft.com/en-us/library/ms912391(v=winembedded.11).aspx
                DateTime d = new DateTime (2014, 6, 11, 18, 0, 0); //June, 11, 2014, 18:00
                d = TimeZoneInfo.ConvertTimeToUtc(d, tm);

                param.Add("LastPositionDate", d.Ticks); //Shows devices registred after the chosen date
                param.Add("LastPositionNumber", "5"); // We want that the registration in the Venice area is one of the last 5 registrations

                HashSet<String> tagmaps = new HashSet<String>();
                tagmaps.Add("Libra"); //Tag number 1
                tagmaps.Add("Virgo"); //Tag number 2

                param.Add("Tags", tagmaps);

                JArray al = await ca.GetDevices(param); //returns devices depending by filters
                //JArray al = await ca.GetDevices(); //returns all devices

                txtbox.AppendText("\r\nGet Devices\r\n");
                if (al != null)
                {
                    for (int i = 0; i < al.Count; i++)
                    {
                        txtbox.AppendText((((JObject)al[i]).GetValue("DeviceId")) + "\r\n");
                        txtbox.AppendText((((JObject)al[i]).GetValue("Expired")) + "\r\n");
                        txtbox.AppendText((((JObject)al[i]).GetValue("DeviceType")) + "\r\n");
                        txtbox.AppendText((((JObject)al[i]).GetValue("Created")) + "\r\n");
                        txtbox.AppendText((((JObject)al[i]).GetValue("Updated")) + "\r\n");
                    }
                }
                else
                {
                    txtbox.AppendText("\r\nError during request\r\n");
                }
            }
            catch (HttpRequestException)
            {
                //"Error during URL request")
                txtbox.AppendText("\r\nError during URL request: problably no connection or wrong URL\r\n");
            }
            catch (Exception)
            {
                txtbox.AppendText("\r\nError during GetDevices\r\n");
            }
        }

        private async void btnGetAppTagFilters_Click(object sender, EventArgs e)
        {
            Credentials cr = new Credentials(ConfigClass.Username, ConfigClass.Password);
            CoreApi ca = new CoreApi(ConfigClass.AppId, cr);

            try
            {
                Dictionary<String, Object> param = new Dictionary<String, Object>();
                param.Add("ReturnHistory", "True");	//If true, returns even the filters used in the past but not associated with any device at the moment (default false)

                JArray al = await ca.GetAppTagFilters(param);

                txtbox.AppendText("\r\nGet App Tags Filters\r\n");
                if (al != null)
                {
                    for (int i = 0; i < al.Count; i++)
                    {
                        txtbox.AppendText(al[i].ToString() + "\r\n");
                    }
                }
                else
                {
                    txtbox.AppendText("\r\nError during request\r\n");
                }
            }
            catch (HttpRequestException)
            {
                //"Error during URL request")
                txtbox.AppendText("\r\nError during URL request: problably no connection or wrong URL\r\n");
            }
            catch (Exception)
            {
                txtbox.AppendText("\r\nError during GetAppTagsFilters\r\n");
            }
        }

        private async void btnGetPushMesseges_Click(object sender, EventArgs e)
        {
            Credentials cr = new Credentials(ConfigClass.Username, ConfigClass.Password);
            CoreApi ca = new CoreApi(ConfigClass.AppId, cr);
            
            try
            {
                Dictionary<String, Object> param = new Dictionary<String, Object>();
                param.Add("DeviceType", "1"); //Apple Platform filter 
                param.Add("Limit", "10");
                param.Add("Offset", "0");
                param.Add("IncludeParams", "True");

                //param.Add("Latitude", "45.44085");
                //param.Add("Longitude", "12.31552");

                TimeZoneInfo tm = TimeZoneInfo.FindSystemTimeZoneById("W. Europe Standard Time"); //http://msdn.microsoft.com/en-us/library/ms912391(v=winembedded.11).aspx
                DateTime d = new DateTime(2014, 6, 11, 18, 0, 0); //June, 11, 2014, 18:00
                d = TimeZoneInfo.ConvertTimeToUtc(d, tm);

                //param.Add("LastPositionDate", d.Ticks);
                //param.Add("LastPositionNumber", "1");

                HashSet<String> tagmaps = new HashSet<String>();
                tagmaps.Add("Libra"); //Tag number 1
                tagmaps.Add("Virgo"); //Tag number 2

                param.Add("Tags", tagmaps);

                JArray al = await ca.GetPushMessages(param);

                txtbox.AppendText("\r\nGet Push Messages\r\n");
                if (al != null)
                {
                    for (int i = 0; i < al.Count; i++)
                    {
                        txtbox.AppendText((((JObject)al[i]).GetValue("PushMessageId")) + "\r\n");
                        txtbox.AppendText((((JObject)al[i]).GetValue("Message")) + "\r\n");
                        txtbox.AppendText((((JObject)al[i]).GetValue("Date")) + "\r\n");
                        txtbox.AppendText((((JObject)((JObject)al[i]).GetValue("Params")).GetValue("Param1")) + "\r\n");
                        txtbox.AppendText((((JObject)((JObject)al[i]).GetValue("Params")).GetValue("Param2")) + "\r\n");
                    }
                }
                else
                {
                    txtbox.AppendText("\r\nError during request\r\n");
                }
            }
            catch (HttpRequestException)
            {
                //"Error during URL request")
                txtbox.AppendText("\r\nError during URL request: problably no connection or wrong URL\r\n");
            }
            catch (Exception)
            {
                txtbox.AppendText("\r\nError during GetPushMessages\r\n");
            }
        }

        private async void btnGetPushMessagesByDevice_Click(object sender, EventArgs e)
        {
            Credentials cr = new Credentials(ConfigClass.Username, ConfigClass.Password);
            CoreApi ca = new CoreApi(ConfigClass.AppId, cr);
            
            try
            {
                Dictionary<String, Object> param = new Dictionary<String, Object>();
                param.Add("DeviceId", "jS0oE8PtHcVerde_7a6ff0f023039299"); //Device ID filter 
                param.Add("Limit", "10");
                param.Add("Offset", "0");
                param.Add("IncludeParams", "True");

                JArray al = await ca.GetPushMessagesByDevice(param);

                txtbox.AppendText("\r\nGet Push Messages By Device\r\n");
                if (al != null)
                {
                    for (int i = 0; i < al.Count; i++)
                    {
                        txtbox.AppendText((((JObject)al[i]).GetValue("PushMessageId")) + "\r\n");
                        txtbox.AppendText((((JObject)al[i]).GetValue("Message")) + "\r\n");
                        txtbox.AppendText((((JObject)al[i]).GetValue("Date")) + "\r\n");
                        txtbox.AppendText((((JObject)((JObject)al[i]).GetValue("Params")).GetValue("Param1")) + "\r\n");
                        txtbox.AppendText((((JObject)((JObject)al[i]).GetValue("Params")).GetValue("Param2")) + "\r\n");
                    }
                }
                else
                {
                    txtbox.AppendText("\r\nError during request\r\n");
                }
            }
            catch (HttpRequestException)
            {
                //"Error during URL request")
                txtbox.AppendText("\r\nError during URL request: problably no connection or wrong URL\r\n");
            }
            catch (Exception)
            {
                txtbox.AppendText("\r\nError during GetPushMessagesByDevice\r\n");
            }
        }

        private async void btnDeletePushMessage_Click(object sender, EventArgs e)
        {
            Credentials cr = new Credentials(ConfigClass.Username, ConfigClass.Password);
            CoreApi ca = new CoreApi(ConfigClass.AppId, cr);
            
            try
            {
                Dictionary<String, Object> param = new Dictionary<String, Object>();
                param.Add("PushMessageId", "jS0oE8PtHcVerde_635381771924100000");

                JObject al = await ca.DeletePushMessages(param);

                txtbox.AppendText("\r\nDelete Push Message\r\n");
                if (al != null)
                {
                    txtbox.AppendText (al.GetValue("Error") + ": " + al.GetValue("Message") + "\r\n");
                }
                else
                {
                    txtbox.AppendText("\r\nError during request\r\n");
                }
            }
            catch (HttpRequestException)
            {
                txtbox.AppendText("\r\nError during URL request: problably no connection or wrong URL\r\n");
            }
            catch (Exception)
            {
                txtbox.AppendText("\r\nError during DeletePushMessages\r\n");
            }
        }

        private async void btnSendPushMessage_Click(object sender, EventArgs e)
        {
            Credentials cr = new Credentials(ConfigClass.Username, ConfigClass.Password);
            CoreApi ca = new CoreApi(ConfigClass.AppId, cr);
            
            try
            {
                Dictionary<String, Object> param = new Dictionary<String, Object>();
                param.Add("Message", "Push message from c# to all WP");
                param.Add("Badge", "2");
                param.Add("Push", "False");
                param.Add("Sound", "Default");

                param.Add("SendIOS", "False");
                param.Add("SendAndroid", "False");
                param.Add("SendBB", "False");
                param.Add("SendWP", "True");	//push sent to WindowsPhone devices

                //param.Add("P1Latitude", "40.42163694648697");
                //param.Add("P1Longitude", "10.299156188964844");
                //param.Add("P2Latitude", "47.45030563100575");
                //param.Add("P2Longitude", "15.368927001953125");

                TimeZoneInfo tm = TimeZoneInfo.FindSystemTimeZoneById("W. Europe Standard Time"); //http://msdn.microsoft.com/en-us/library/ms912391(v=winembedded.11).aspx
                DateTime d = new DateTime(2014, 6, 11, 18, 0, 0); //June, 11, 2014, 18:00
                d = TimeZoneInfo.ConvertTimeToUtc(d, tm);

                //param.Add("LastPositionDate", d.Ticks);
                //param.Add("LastPositionNumber", 5);

                HashSet<String> tags = new HashSet<String>();
                tags.Add("Libra");

                param.Add("Tags", tags);


                Dictionary<String, String> pars = new Dictionary<String, String>();
                pars.Add("Param1", "Param number 1");
                pars.Add("Param2", "https://www.facebook.com/OfficialPuship");
                pars.Add("Param3", "index.html");
                pars.Add("Param4", "122.45");
                pars.Add("Param5", "Special chars:  \'%1234567890\"!£$%&/()=?^éè@#°§ù-,'"); //max 5 params
                param.Add("Params", pars);


                JObject al = await ca.SendPushMessage(param);

                txtbox.AppendText("\r\nSend Push Message\r\n");
                if (al != null)
                {
                    txtbox.AppendText(al.GetValue("Error") + ": " + al.GetValue("Message") + "\r\n");
                }
                else
                {
                    txtbox.AppendText("\r\nError during request\r\n");
                }
            }
            catch (HttpRequestException)
            {
                //"Error during URL request")
                txtbox.AppendText("\r\nError during URL request: problably no connection or wrong URL\r\n");
            }
            catch (Exception)
            {
                //generic error
                txtbox.AppendText("\r\nError during SendPushMessage\r\n");
            }
        }

        private async void btnSendPushMessageByDevice_Click(object sender, EventArgs e)
        {
            Credentials cr = new Credentials(ConfigClass.Username, ConfigClass.Password);
            CoreApi ca = new CoreApi(ConfigClass.AppId, cr);

            try
            {
                Dictionary<String, Object> param = new Dictionary<String, Object>();
                param.Add("Message", "Push message to android from c#");
                param.Add("Badge", "2");
                param.Add("Push", "True");
                param.Add("Sound", "Default");

                HashSet<String> devicetosend = new HashSet<String>();
                devicetosend.Add("jS0oE8PtHcVerde_7a6ff0f0230392994"); //push sent to Android device
                param.Add("Devices", devicetosend);

                Dictionary<String, String> pars = new Dictionary<String, String>();
                pars.Add("Param1", "Param number 1");
                pars.Add("Param2", "https://www.facebook.com/OfficialPuship");
                pars.Add("Param3", "index.html");
                pars.Add("Param4", "122.45");
                pars.Add("Param5", "Special chars:  \'%1234567890\"!£$%&/()=?^éè@#°§ù-,'"); //max 5 params
                param.Add("Params", pars);

                JObject al = await ca.SendPushMessageByDevice(param);

                txtbox.AppendText("\r\nSend Push Message By Device\r\n");
                if (al != null)
                {
                    txtbox.AppendText(al.GetValue("Error") + ": " + al.GetValue("Message") + "\r\n");
                }
                else
                {
                    txtbox.AppendText("\r\nError during request\r\n");
                }
            }
            catch (HttpRequestException)
            {
                //"Error during URL request")
                txtbox.AppendText("\r\nError during URL request: problably no connection or wrong URL\r\n");
            }
            catch (Exception)
            {
                //generic error
                txtbox.AppendText("\r\nError during SendPushMessageByDevice\r\n");
            }
        }

        private void btnClear_Click(object sender, EventArgs e)
        {
            txtbox.Clear();
        }

        private async void btnGetApps_Click(object sender, EventArgs e)
        {
            Credentials cr = new Credentials(ConfigClass.Username, ConfigClass.Password);
            CoreApi ca = new CoreApi(ConfigClass.AppId, cr);

            try
            {
                Dictionary<String, Object> param = new Dictionary<String, Object>();
                param.Add("Limit", "10");
                param.Add("Offset", "0");


                JArray al = await ca.GetApps(param); //returns devices depending by filters

                txtbox.AppendText("\r\nGet Apps\r\n");
                if (al != null)
                {
                    for (int i = 0; i < al.Count; i++)
                    {
                        txtbox.AppendText((((JObject)al[i]).GetValue("Name")) + "\r\n");
                        txtbox.AppendText((((JObject)al[i]).GetValue("AccessCode")) + "\r\n");
                        txtbox.AppendText((((JObject)al[i]).GetValue("EnableAPNS")) + "\r\n");
                        txtbox.AppendText((((JObject)al[i]).GetValue("EnableBPNS")) + "\r\n");
                        txtbox.AppendText((((JObject)al[i]).GetValue("EnableMPNS")) + "\r\n");
                        txtbox.AppendText((((JObject)al[i]).GetValue("EnableGCM")) + "\r\n");
                        txtbox.AppendText((((JObject)al[i]).GetValue("Created")) + "\r\n");
                        txtbox.AppendText((((JObject)al[i]).GetValue("Updated")) + "\r\n");
                    }
                }
                else
                {
                    txtbox.AppendText("\r\nError during request\r\n");
                }
            }
            catch (HttpRequestException)
            {
                //"Error during URL request")
                txtbox.AppendText("\r\nError during URL request: problably no connection or wrong URL\r\n");
            }
            catch (Exception)
            {
                txtbox.AppendText("\r\nError during GetApps\r\n");
            }
        }
    }
}
